# coding: utf-8

"""
    Mentortools Internal Sntegrations API

    Mentortools service for handling internal integrations

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class AddNewStreamRecordingToModule(BaseModel):
    """
    AddNewStreamRecordingToModule
    """
    portal_id: StrictInt = Field(...)
    parent_folder_id: Optional[StrictInt] = None
    thumbnail_file_id: Optional[StrictStr] = None
    module_id: StrictInt = Field(...)
    autopublish: StrictBool = Field(...)
    stream_download_url: StrictStr = Field(...)
    stream_download_headers: Dict[str, Any] = Field(...)
    __properties = ["portal_id", "parent_folder_id", "thumbnail_file_id", "module_id", "autopublish", "stream_download_url", "stream_download_headers"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AddNewStreamRecordingToModule:
        """Create an instance of AddNewStreamRecordingToModule from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AddNewStreamRecordingToModule:
        """Create an instance of AddNewStreamRecordingToModule from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AddNewStreamRecordingToModule.parse_obj(obj)

        _obj = AddNewStreamRecordingToModule.parse_obj({
            "portal_id": obj.get("portal_id"),
            "parent_folder_id": obj.get("parent_folder_id"),
            "thumbnail_file_id": obj.get("thumbnail_file_id"),
            "module_id": obj.get("module_id"),
            "autopublish": obj.get("autopublish"),
            "stream_download_url": obj.get("stream_download_url"),
            "stream_download_headers": obj.get("stream_download_headers")
        })
        return _obj


